@@ -1,14 +1,17 @@
 """AKShare helpers module."""
 
 # pylint: disable=unused-argument,too-many-arguments,too-many-branches,too-many-locals,too-many-statements
-import re
 from typing import Dict, Any, List, Optional, Union
-
+import pandas as pd
 from openbb_core.provider.utils.errors import EmptyDataError
 from openbb_yfinance.utils.references import INTERVALS, MONTHS, PERIODS
 from pandas import DataFrame
-from datetime import datetime, timedelta
+from datetime import (
+    date as dateType,
+    datetime,
+)
 from .tools import normalize_date, normalize_symbol
+import akshare as ak
 
 import logging
 from openbb_akshare.utils.tools import setup_logger, normalize_symbol
@@ -16,32 +19,117 @@ from openbb_akshare.utils.tools import setup_logger, normalize_symbol
 #setup_logger()
 logger = logging.getLogger(__name__)
 
-def ak_download(  # pylint: disable=too-many-positional-arguments
-    symbol: str,
-    start_date: Optional[Union[str, "date"]] = None,
-    end_date: Optional[Union[str, "date"]] = None,
-    interval: INTERVALS = "1d",
-    period: Optional[PERIODS] = None,
-    use_cache: Optional[bool] = True,
-    **kwargs: Any,
-) -> DataFrame:
-    import akshare as ak
+EQUITY_HISTORY_SCHEMA = {
+    "date": "TEXT PRIMARY KEY",
+    "open": "REAL",
+    "high": "REAL",
+    "low": "REAL",
+    "close": "REAL",
+    "volume": "REAL",
+    "vwap": "REAL",
+    "change": "REAL",
+    "change_percent": "REAL",
+    "amount": "REAL"
+}
 
-    start = start_date.strftime("%Y%m%d")
-    end = end_date.strftime("%Y%m%d")
+def ak_download_without_cache(
+        symbol: str,
+        start_date: str,
+        end_date: str,
+        period: str = "daily",
+        adjust: str = "",
+    ) -> DataFrame:
 
     symbol_b, symbol_f, market = normalize_symbol(symbol)
     if market == "HK":
-        hist_df = ak.stock_hk_hist(symbol_b, period, start, end, adjust="")
+        hist_df = ak.stock_hk_hist(symbol_b, period, start_date, end_date, adjust="")
+        hist_df.rename(columns={"日期": "date", "开盘": "open", "收盘": "close", "最高": "high", "最低": "low", "成交量": "volume", "成交额": "amount", "涨跌幅":"change_percent", "涨跌额": "change"}, inplace=True)
+        hist_df = hist_df.drop(columns=["振幅"])
+        hist_df = hist_df.drop(columns=["换手率"])
     else:
-        hist_df = ak.stock_zh_a_hist(symbol_b, period, start, end, adjust="")
+        hist_df = ak.stock_zh_a_hist(symbol_b, period, start_date, end_date, adjust="")
     
-    hist_df.rename(columns={"日期": "date", "股票代码": "symbol", "开盘": "open", "收盘": "close", "最高": "high", "最低": "low", "成交量": "volume", "成交额": "amount", "涨跌幅":"change_percent", "涨跌额": "change"}, inplace=True)
-    hist_df = hist_df.drop(columns=["振幅"])
-    hist_df = hist_df.drop(columns=["换手率"])
+        hist_df.rename(columns={"日期": "date", "开盘": "open", "收盘": "close", "最高": "high", "最低": "low", "成交量": "volume", "成交额": "amount", "涨跌幅":"change_percent", "涨跌额": "change"}, inplace=True)
+        hist_df = hist_df.drop(columns=["股票代码"])
+        hist_df = hist_df.drop(columns=["振幅"])
+        hist_df = hist_df.drop(columns=["换手率"])
+
     return hist_df
 
 
+def ak_download_with_cache(
+        symbol: str,
+        start_date: str,
+        end_date: str,
+        period: str = "daily",
+        adjust: str = "",
+    ) -> DataFrame:
+    """
+    Retrieves historical equity data from a cache or downloads it from a remote source.
+    
+    Handles:
+        - Non-dividend cases (return 0)
+        - Per-share direct values (e.g., "每股0.38港元")
+        - Base-share values (e.g., "10派1元")
+        - Complex combinations (e.g., "每股派发现金股利0.088332港元,每10股派送股票股利3股")
+
+    Parameters:
+        symbol (str): Stock symbol to fetch data for.
+        start_date (str): Start date for fetching data in 'YYYYMMDD' format.
+        end_date (str): End date for fetching data in 'YYYYMMDD' format.
+        period (str): Data frequency, e.g., "daily", "weekly", "monthly".
+        adjust (str): Adjustment type, e.g., "qfq" for forward split, "hfq" for backward split.
+
+    Returns:
+        DataFrame: DataFrame containing historical equity data.
+    """
+    from openbb_akshare.utils.equity_cache import EquityCache
+    from openbb_akshare.utils.helpers import EQUITY_HISTORY_SCHEMA
+    from openbb_akshare.utils.fetch_equity_info import fetch_equity_info
+
+    # Retrieve data from cache first
+    symbol_b, symbol_f, market = normalize_symbol(symbol)
+    cache = EquityCache(EQUITY_HISTORY_SCHEMA, table_name=f"{market}{symbol_b}")
+    start_dt = datetime.strptime(start_date, "%Y%m%d")
+    end_dt = datetime.strptime(end_date, "%Y%m%d")
+
+    start = start_dt.strftime("%Y-%m-%d")
+    end = end_dt.strftime("%Y-%m-%d")
+    data_from_cache = cache.fetch_date_range(start, end)
+    if not data_from_cache.empty:
+        return data_from_cache
+
+    # If not in cache, download data
+    equity_info = fetch_equity_info(symbol_b)
+    listed_date = pd.to_datetime(equity_info["listed_date"], unit='ms')
+    
+    first_stock_price_date = listed_date.iloc[0].strftime('%Y%m%d')
+    today = datetime.now().date().strftime("%Y%m%d")
+    # Download data using AKShare
+    data_util_today_df = ak_download_without_cache(symbol=symbol_b, period=period, start_date=first_stock_price_date, end_date=today, adjust="")
+    cache.write_dataframe(data_util_today_df)
+    
+    return cache.fetch_date_range(start, end)
+
+def ak_download(
+        symbol: str,
+        start_date: dateType,
+        end_date: dateType,
+        period: str = "daily",
+        use_cache: Optional[bool] = True,
+        adjust: str = "",
+    ) -> DataFrame:
+
+    start = start_date.strftime("%Y%m%d")
+    end = end_date.strftime("%Y%m%d")
+    if use_cache:
+        return ak_download_with_cache(symbol, start, end, period, adjust)
+    
+    result = ak_download_without_cache(symbol, start, end, period, adjust)
+
+    return result
+
+
 def get_post_tax_dividend_per_share(dividend_str: str) -> float:
     """
     Parses Chinese dividend descriptions and returns post-tax dividend per share.
